perl -I../lib file.t 1
perl -I../lib is.t 1
perl -I../lib ok.t 1
perl -I../lib require_ok.t 1
perl -I../lib skip_all.t 1
perl -I../lib tests.t 1
perl -I../lib use_ok.1.t 1
perl -I../lib use_ok.2.t 1
perl -I../lib use_ok.3.t 1
